@@ -56,7 +56,8 @@ plot.aftreg <- function(x,
         oldpar <- par(mfrow = c(2, 1))
         on.exit(par(oldpar))
     }
-    ncov <- length(x$means)
+    ##ncov <- length(x$means) # Doesn't work with some factor covariates!!
+    ncov <- x$df
     ns <- x$n.strata
     param.scale <- if (x$param=="lifeAcc") -1 else 1
     if (x$pfixed){
@@ -130,7 +131,7 @@ plot.aftreg <- function(x,
         if (is.null(ylim)) ylim <- c(0, max(haz))
         if (min(p) < 1) ylim[2] <- min(ylim[2], max(haz[, -1]))
 
-        if (is.null(xlab)) xlab <- "Duration"
+        ##if (is.null(xlab)) xlab <- "Duration"
         if (is.null(ylab)) ylab <- "Hazard"
         if (is.null(main)) main <- paste(dist, "hazard function")
         plot(xx, haz[1, ], type = "l", xlim = xlim, ylim = ylim,
@@ -154,9 +155,9 @@ plot.aftreg <- function(x,
         }
         ylim <- c(0, max(Haz))
         ##if (is.null(xlab))
-        xlab <- "Duration"
+        ##xlab <- "Duration"
         ##if (is.null(ylab))
-        ylab <- "Cumulative Hazard"
+        ylab <- "Cumulative Hazards"
         ##if (is.null(main))
         main <- paste(dist, "cumulative hazard function")
         plot(xx, Haz[1, ], type = "l", xlim = xlim, ylim = ylim,
@@ -189,7 +190,7 @@ plot.aftreg <- function(x,
         if (min(p) < 1) ylim[2] <- min(max(den[, -1]))
 
         ##if (is.null(xlab))
-        xlab <- "Duration"
+        ##xlab <- "Duration"
         ##if (is.null(ylab))
         ylab <- "Density"
         ##if (is.null(main))
@@ -226,7 +227,7 @@ plot.aftreg <- function(x,
         ylim <- c(0, 1)
 
         ##if (is.null(xlab))
-        xlab <- "Duration"
+        ##xlab <- "Duration"
         ##if (is.null(ylab))
         ylab <- "Survival"
         ##if (is.null(main))
